import { scaleLinear, extent } from 'd3';
import { axes } from './axes';

export const scatterPlot = (selection, options) => {
  const {
    data,
    width,
    height,
    xValue,
    yValue,
    margin,
    xAxisLabel,
    yAxisLabel,
  } = options;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const marks = data.map((d) => ({
    x: xScale(xValue(d)),
    y: yScale(yValue(d)),
  }));

  selection.call(axes, { xScale, yScale, xAxisLabel, yAxisLabel });

  // Render a Scatter Plot
  selection
    .selectAll('circle')
    .data(marks)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 5);
};
