import { select, csvParse, min, max, extent } from 'd3';
import { scatterPlot } from './scatterPlot';

export const viz = (container, options) => {
  const [state, setState] = options;
  const { data } = state;

  const width = innerWidth;
  const height = innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  if (data && data !== 'LOADING') {
    const xValue = (d) => d.sepal_length;
    const yValue = (d) => d.petal_length;

    svg.call(scatterPlot, {
      data,
      width,
      height,
      xValue,
      yValue,
      xAxisLabel: 'Sepal Length',
      yAxisLabel: 'Petal Length',
      margin: {
        top: 20,
        left: 60,
        bottom: 60,
        right: 20,
      },
    });
  }

  if (!data) {
    setState((prev) => ({ ...prev, data: 'LOADING' }));

    fetch('data.csv')
      .then((res) => res.text())
      .then((csvString) => {
        const data = csvParse(csvString);

        data.forEach((d) => {
          (d.sepal_length = +d.sepal_length),
            (d.sepal_width = +d.sepal_width),
            (d.petal_width = +d.petal_width),
            (d.petal_length = +d.petal_length);
        });

        setState((prev) => ({ ...prev, data: data }));
      });
  }
};
